<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class UACF7_IP_GEOLOCATION {

	/*
	 * Construct function
	 */
	public function __construct() {


		require_once 'inc/functions.php';

		add_action( 'wpcf7_init', array( $this, 'add_shortcodes' ) );

		add_action( 'admin_init', array( $this, 'tag_generator' ) );

		add_filter( 'wpcf7_validate_uacf7_city', array( $this, 'wpcf7_fields_validation_filter' ), 10, 2 );
		add_filter( 'wpcf7_validate_uacf7_city*', array( $this, 'wpcf7_fields_validation_filter' ), 10, 2 );

		add_filter( 'wpcf7_validate_uacf7_state', array( $this, 'wpcf7_fields_validation_filter' ), 10, 2 );
		add_filter( 'wpcf7_validate_uacf7_state*', array( $this, 'wpcf7_fields_validation_filter' ), 10, 2 );

		add_filter( 'wpcf7_validate_uacf7_zip', array( $this, 'wpcf7_fields_validation_filter' ), 10, 2 );
		add_filter( 'wpcf7_validate_uacf7_zip*', array( $this, 'wpcf7_fields_validation_filter' ), 10, 2 );
		// add_action( 'wpcf7_swv_create_schema', array( $this, 'uacf7_swv_add_geo_location_rules' ), 10, 2 );

		add_filter( 'uacf7_tag_generator_country_autocomplete_field', array( $this, 'uacf7_tag_generator_country_autocomplete_field' ), 10, 2 );
		add_filter( 'uacf7_tag_generator_default_country_field', array( $this, 'uacf7_tag_generator_default_country_field' ), 10, 2 );
		add_filter( 'uacf7_get_country_attr', array( $this, 'uacf7_get_country_attr' ), 10, 3 );

		add_filter( 'uacf7_tag_generator_dynamic_selection', [ $this, 'uacf7_tag_generator_dynamic_selection' ], 10, 2 );
		add_filter( 'uacf7_api_based_country_filter', [ $this, 'uacf7_api_based_country_filter' ], 10, 2 );


		add_filter( 'uacf7_save_admin_menu', array( $this, 'uacf7_save_ip_geo_fields' ), 10, 2 );
		add_action( 'wp_enqueue_scripts', array( $this, 'uacf7_enqueue_scripts' ) );

		//

	}

	//Pro IP GEO location scripts
	public function uacf7_enqueue_scripts() {
		wp_enqueue_script( 'uacf7-api-script', plugin_dir_url( __FILE__ ) . 'assets/js/all-country-info.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'uacf7-geo-api-openstreetmap-script', plugin_dir_url( __FILE__ ) . 'assets/js/geo-api.js', array( 'jquery' ), null, true );
		wp_localize_script( 'uacf7-api-script', 'all_country_script',
			array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'plugin_dir_url' => plugin_dir_url( __FILE__ ),
			)
		);
	}

	/*
	 * Form tag
	 */
	public function add_shortcodes() {

		wpcf7_add_form_tag( array( 'uacf7_city', 'uacf7_city*' ),
			array( $this, 'tag_handler_city' ), array( 'name-attr' => true ) );

		wpcf7_add_form_tag( array( 'uacf7_state', 'uacf7_state*' ),
			array( $this, 'tag_handler_state' ), array( 'name-attr' => true ) );

		wpcf7_add_form_tag( array( 'uacf7_zip', 'uacf7_zip*' ),
			array( $this, 'tag_handler_zip' ), array( 'name-attr' => true ) );
	}

	public function tag_handler_city( $tag ) {

		if ( empty( $tag->name ) ) {
			return '';
		}

		$validation_error = wpcf7_get_validation_error( $tag->name );

		$class = wpcf7_form_controls_class( $tag->type );

		if ( $validation_error ) {
			$class .= ' wpcf7-not-valid';
		}

		$atts = array();

		$atts['class'] = $tag->get_class_option( $class );
		$atts['id'] = $tag->get_id_option();
		$atts['tabindex'] = $tag->get_option( 'tabindex', 'signed_int', true );

		if ( $tag->is_required() ) {
			$atts['aria-required'] = 'true';
		}

		$atts['aria-invalid'] = $validation_error ? 'true' : 'false';

		$atts['name'] = $tag->name;

		$size = $tag->get_option( 'size', 'int', true );

		if ( $size ) {
			$atts['size'] = $size;
		} else {
			//$atts['size'] = 40;
		}
		/** Dynamic Selection from API Based on Country & State */
		$ds_city = $tag->has_option( 'ds_city' );
		if ( $ds_city ) {
			$atts['ds_city'] = 'true';
		}

		/** Auto Complete */
		$city_auto_complete = $tag->has_option( 'city_auto_complete' );


		if ( $city_auto_complete ) {
			$atts['city_auto_complete'] = 'true';
		}

		$placeholder = $tag->get_option( 'placeholder' );
		if ( ! empty( $placeholder ) ) {
			$placeholder = $placeholder[0];
		} else {
			$placeholder = '';
		}


		$atts = wpcf7_format_atts( $atts );

		ob_start();
		?>
		<span data-name="<?php echo esc_attr( $tag->name ); ?>" id="uacf7_city"
			class="wpcf7-form-control-wrap <?php echo sanitize_html_class( $tag->name ); ?>">

			<style>
				@keyframes spin {
					0% {
						transform: rotate(0deg);
					}

					100% {
						transform: rotate(360deg);
					}
				}
			</style>

			<div id="preloader"
				style="display:none; position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); border: 8px solid #f3f3f3; border-radius: 50%; border-top: 8px solid #3498db; width: 60px; height: 60px; animation: spin 2s linear infinite; z-index: 999999;">
			</div>

			<?php if ( $ds_city ) { ?>
				<select <?php echo $atts; ?> id="uacf7_city_api">
					<option value="">Select a City</option>
				</select>
			<?php } else { ?>

				<span>
					<input placeholder="<?php echo esc_html( $placeholder ); ?>"
						id="uacf7_city_<?php echo esc_attr( $tag->name ); ?>" type="text" <?php echo $atts; ?>>
				</span>
				<span><?php echo $validation_error; ?></span>

			<?php } ?>

		</span>
		<?php

		$countries = ob_get_clean();

		return $countries;
	}




	/** API Based Country Showing */

	public function uacf7_api_based_country_filter( $val, $atts ) { ?>
		<select <?php echo $atts; ?> id="uacf7_country_api">
			<option value="">Select a Country</option>
		</select>
	<?php }

	public function tag_handler_state( $tag ) {

		if ( empty( $tag->name ) ) {
			return '';
		}


		$validation_error = wpcf7_get_validation_error( $tag->name );

		$class = wpcf7_form_controls_class( $tag->type );

		if ( $validation_error ) {
			$class .= ' wpcf7-not-valid';
		}

		$atts = array();

		$atts['class'] = $tag->get_class_option( $class );
		$atts['id'] = $tag->get_id_option();
		$atts['tabindex'] = $tag->get_option( 'tabindex', 'signed_int', true );

		if ( $tag->is_required() ) {
			$atts['aria-required'] = 'true';
		}

		$atts['aria-invalid'] = $validation_error ? 'true' : 'false';

		$atts['name'] = $tag->name;

		$size = $tag->get_option( 'size', 'int', true );

		if ( $size ) {
			$atts['size'] = $size;
		} else {
			//$atts['size'] = 40;
		}

		$ds_state = $tag->has_option( 'ds_state' );
		if ( $ds_state ) {
			$atts['ds_state'] = 'true';
		}

		/** Auto Complete */
		$state_auto_complete = $tag->has_option( 'state_auto_complete' );


		if ( $state_auto_complete ) {
			$atts['state_auto_complete'] = 'true';
		}


		$placeholder = $tag->get_option( 'placeholder' );
		if ( ! empty( $placeholder ) ) {
			$placeholder = $placeholder[0];
		} else {
			$placeholder = '';
		}

		$atts = wpcf7_format_atts( $atts );

		ob_start();
		?>
		<span data-name="<?php echo esc_attr( $tag->name ); ?>" id="uacf7_state"
			class="wpcf7-form-control-wrap <?php echo sanitize_html_class( $tag->name ); ?>">

			<div id="preloader"
				style="display:none; position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); border: 8px solid #f3f3f3; border-radius: 50%; border-top: 8px solid #3498db; width: 60px; height: 60px; animation: spin 2s linear infinite; z-index: 999999;">
			</div>

			<?php if ( $ds_state ) { ?>
				<select <?php echo $atts; ?> id="uacf7_state_api">
					<option value="">Select a State</option>
				</select>
			<?php } else { ?>
				<span>
					<input placeholder="<?php echo esc_html( $placeholder ); ?>"
						id="uacf7_state_<?php echo esc_attr( $tag->name ); ?>" type="text" <?php echo $atts; ?>>
				</span>
				<span><?php echo $validation_error; ?></span>

			<?php } ?>



		</span>
		<?php

		$countries = ob_get_clean();

		return $countries;
	}

	public function tag_handler_zip( $tag ) {

		if ( empty( $tag->name ) ) {
			return '';
		}


		$validation_error = wpcf7_get_validation_error( $tag->name );

		$class = wpcf7_form_controls_class( $tag->type );

		if ( $validation_error ) {
			$class .= ' wpcf7-not-valid';
		}

		$atts = array();

		$atts['class'] = $tag->get_class_option( $class );
		$atts['id'] = $tag->get_id_option();
		$atts['tabindex'] = $tag->get_option( 'tabindex', 'signed_int', true );

		if ( $tag->is_required() ) {
			$atts['aria-required'] = 'true';
		}

		$atts['aria-invalid'] = $validation_error ? 'true' : 'false';

		$atts['name'] = $tag->name;

		$size = $tag->get_option( 'size', 'int', true );

		if ( $size ) {
			$atts['size'] = $size;
		} else {
			//$atts['size'] = 40;
		}

		/** Auto Complete */
		$zip_auto_complete = $tag->has_option( 'zip_auto_complete' );


		if ( $zip_auto_complete ) {
			$atts['zip_auto_complete'] = 'true';
		}

		$placeholder = $tag->get_option( 'placeholder' );
		if ( ! empty( $placeholder ) ) {
			$placeholder = $placeholder[0];
		} else {
			$placeholder = '';
		}

		$atts = wpcf7_format_atts( $atts );

		ob_start();
		?>
		<span data-name="<?php echo esc_attr( $tag->name ); ?>" id="uacf7_zip"
			class="wpcf7-form-control-wrap <?php echo sanitize_html_class( $tag->name ); ?>">
			<div id="preloader"
				style="display:none; position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); border: 8px solid #f3f3f3; border-radius: 50%; border-top: 8px solid #3498db; width: 60px; height: 60px; animation: spin 2s linear infinite; z-index: 999999;">
			</div>
			<span>
				<input placeholder="<?php echo esc_html( $placeholder ); ?>"
					id="uacf7_zip_<?php echo esc_attr( $tag->name ); ?>" type="text" <?php echo $atts; ?>>
			</span>
			<span><?php echo $validation_error; ?></span>
		</span>
		<?php

		$countries = ob_get_clean();

		return $countries;
	}

	public function wpcf7_fields_validation_filter( $result, $tag ) {
		$name = $tag->name;

		if ( isset( $_POST[ $name ] )
			and is_array( $_POST[ $name ] ) ) {
			foreach ( $_POST[ $name ] as $key => $value ) {
				if ( '' === $value ) {
					unset( $_POST[ $name ][ $key ] );
				}
			}
		}

		$empty = ! isset( $_POST[ $name ] ) || empty( $_POST[ $name ] ) && '0' !== $_POST[ $name ];

		if ( $tag->is_required() and $empty ) {
			$result->invalidate( $tag, wpcf7_get_message( 'invalid_required' ) );
		}

		return $result;
	}

	/*
	 * Generate tags
	 */
	public function tag_generator() {
		if ( ! function_exists( 'wpcf7_add_tag_generator' ) )
			return;

		wpcf7_add_tag_generator( 'uacf7_city',
			__( 'City', 'ultimate-addons-cf7' ),
			'uacf7-tg-pane-city',
			array( $this, 'tg_pane_city' )
		);

		wpcf7_add_tag_generator( 'uacf7_state',
			__( 'State', 'ultimate-addons-cf7' ),
			'uacf7-tg-pane-state',
			array( $this, 'tg_pane_state' )
		);

		wpcf7_add_tag_generator( 'uacf7_zip',
			__( 'Zip Code', 'ultimate-addons-cf7' ),
			'uacf7-tg-pane-zip',
			array( $this, 'tg_pane_zip' )
		);

	}

	static function tg_pane_city( $contact_form, $args = '' ) {
		$args = wp_parse_args( $args, array() );
		$uacf7_field_type = 'uacf7_city';
		?>
		<div class="control-box">
			<fieldset>
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">Field type</th>
							<td>
								<fieldset>
									<legend class="screen-reader-text">Field type</legend>
									<label><input type="checkbox" name="required" value="on"> Required field</label>
								</fieldset>
							</td>
						</tr>

						<tr>
							<th scope="row"><label
									for="<?php echo esc_attr( $args['content'] . '-name' ); ?>"><?php echo esc_html( __( 'Name', 'ultimate-addons-cf7' ) ); ?></label>
							</th>
							<td><input type="text" name="name" class="tg-name oneline"
									id="<?php echo esc_attr( $args['content'] . '-name' ); ?>" /></td>
						</tr>
						<tr>
							<th scope="row"><label for="placeholder">Placeholder</label></th>
							<td><input type="text" name="placeholder" class="placeholdervalue oneline option" id="placeholder">
							</td>
						</tr>
						<tr class="uacf7-spacer"></tr>
						<tr>
							<th scope="row"><label
									for="city_auto_complete"><?php echo esc_html( __( 'Auto complete', 'ultimate-addons-cf7' ) ); ?></label>
							</th>
							<td><input id="city_auto_complete" type="checkbox" name="city_auto_complete" class="option"
									value="on"> Autocomplete City field using user's network IP.</td>
						</tr>
						<tr class="uacf7-spacer"></tr>
						<tr>
							<th scope="row"><label
									for="ds_city"><?php echo esc_html( __( 'Dynamic Selection', 'ultimate-addons-cf7' ) ); ?></label>
							</th>
							<td><input id="ds_city" type="checkbox" name="ds_city" class="option" value="on">
								<?php echo esc_html( __( "Automatically retrieve the city based on the selected country and state. Note: This function works only if the 'Dynamic Selection for State' option is activated.", "ultimate-addons-cf7" ) ); ?>
							</td>
						</tr>
						<tr class="uacf7-spacer"></tr>
						<tr>
							<th scope="row"><label for="tag-generator-panel-text-class">Class attribute</label></th>
							<td><input type="text" name="class" class="classvalue oneline option"
									id="tag-generator-panel-text-class"></td>
						</tr>
					</tbody>
				</table>
				<div class="uacf7-doc-notice">Confused? Check our Documentation on <a
						href="https://themefic.com/docs/uacf7/free-addons/contact-form-7-country-dropdown-with-flag/"
						target="_blank">Country Dropdown</a> and <a
						href="https://themefic.com/docs/uacf7/pro-addons/contact-form-7-autocomplete/" target="_blank">IP Geo
						Fields (Autocomplete)</a>.</div>
			</fieldset>
		</div>

		<div class="insert-box">
			<input type="text" name="<?php echo esc_attr( $uacf7_field_type ); ?>" class="tag code" readonly="readonly"
				onfocus="this.select()" />

			<div class="submitbox">
				<input type="button" class="button button-primary insert-tag"
					value="<?php echo esc_attr( __( 'Insert Tag', 'ultimate-addons-cf7' ) ); ?>" />
			</div>
		</div>
		<?php
	}

	static function tg_pane_state( $contact_form, $args = '' ) {
		$args = wp_parse_args( $args, array() );
		$uacf7_field_type = 'uacf7_state';
		?>
		<div class="control-box">
			<fieldset>
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">Field type</th>
							<td>
								<fieldset>
									<legend class="screen-reader-text">Field type</legend>
									<label><input type="checkbox" name="required" value="on"> Required field</label>
								</fieldset>
							</td>
						</tr>

						<tr>
							<th scope="row"><label
									for="<?php echo esc_attr( $args['content'] . '-name' ); ?>"><?php echo esc_html( __( 'Name', 'ultimate-addons-cf7' ) ); ?></label>
							</th>
							<td><input type="text" name="name" class="tg-name oneline"
									id="<?php echo esc_attr( $args['content'] . '-name' ); ?>" /></td>
						</tr>
						<tr>
							<th scope="row"><label for="placeholder">Placeholder</label></th>
							<td><input type="text" name="placeholder" class="placeholdervalue oneline option" id="placeholder">
							</td>
						</tr>
						<tr class="uacf7-spacer"></tr>
						<tr>
							<th scope="row"><label
									for="state_auto_complete"><?php echo esc_html( __( 'Auto complete', 'ultimate-addons-cf7' ) ); ?></label>
							</th>
							<td><input id="state_auto_complete" type="checkbox" name="state_auto_complete" class="option"
									value="on"> Autocomplete State field using user's network IP.</td>
						</tr>
						<tr class="uacf7-spacer"></tr>
						<tr>
							<th scope="row"><label
									for="ds_state"><?php echo esc_html( __( 'Dynamic Selection', 'ultimate-addons-cf7' ) ); ?></label>
							</th>
							<td><input id="ds_state" type="checkbox" name="ds_state" class="option" value="on">
								<?php echo esc_html( __( "Dynamically obtain the state based on the chosen country. Note: This feature is operational only if the 'Dynamic Selection for Country' option is enabled.", "ultimate-addons-cf7" ) ); ?>
							</td>
						</tr>
						<tr class="uacf7-spacer"></tr>
						<tr>
							<th scope="row"><label for="tag-generator-panel-text-class">Class attribute</label></th>
							<td><input type="text" name="class" class="classvalue oneline option"
									id="tag-generator-panel-text-class"></td>
						</tr>
					</tbody>
				</table>
				<div class="uacf7-doc-notice">Confused? Check our Documentation on <a
						href="https://themefic.com/docs/uacf7/free-addons/contact-form-7-country-dropdown-with-flag/"
						target="_blank">Country Dropdown</a> and <a
						href="https://themefic.com/docs/uacf7/pro-addons/contact-form-7-autocomplete/" target="_blank">IP Geo
						Fields (Autocomplete)</a>.</div>
			</fieldset>
		</div>

		<div class="insert-box">
			<input type="text" name="<?php echo esc_attr( $uacf7_field_type ); ?>" class="tag code" readonly="readonly"
				onfocus="this.select()" />

			<div class="submitbox">
				<input type="button" class="button button-primary insert-tag"
					value="<?php echo esc_attr( __( 'Insert Tag', 'ultimate-addons-cf7' ) ); ?>" />
			</div>
		</div>
		<?php
	}

	static function tg_pane_zip( $contact_form, $args = '' ) {
		$args = wp_parse_args( $args, array() );
		$uacf7_field_type = 'uacf7_zip';
		?>
		<div class="control-box">
			<fieldset>
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">Field type</th>
							<td>
								<fieldset>
									<legend class="screen-reader-text">Field type</legend>
									<label><input type="checkbox" name="required" value="on"> Required field</label>
								</fieldset>
							</td>
						</tr>

						<tr>
							<th scope="row"><label
									for="<?php echo esc_attr( $args['content'] . '-name' ); ?>"><?php echo esc_html( __( 'Name', 'ultimate-addons-cf7' ) ); ?></label>
							</th>
							<td><input type="text" name="name" class="tg-name oneline"
									id="<?php echo esc_attr( $args['content'] . '-name' ); ?>" /></td>
						</tr>
						<tr>
							<th scope="row"><label for="placeholder">Placeholder</label></th>
							<td><input type="text" name="placeholder" class="placeholdervalue oneline option" id="placeholder">
							</td>
						</tr>
						<tr class="uacf7-spacer"></tr>
						<tr>
							<th scope="row"><label
									for="zip_auto_complete"><?php echo esc_html( __( 'Auto complete', 'ultimate-addons-cf7' ) ); ?></label>
							</th>
							<td><input id="zip_auto_complete" type="checkbox" name="zip_auto_complete" class="option"
									value="on"> Autocomplete zip code field using user's network IP.</td>
						</tr>
						<tr class="uacf7-spacer"></tr>
						<tr>
							<th scope="row"><label for="tag-generator-panel-text-class">Class attribute</label></th>
							<td><input type="text" name="class" class="classvalue oneline option"
									id="tag-generator-panel-text-class"></td>
						</tr>
					</tbody>
				</table>
				<div class="uacf7-doc-notice">Confused? Check our Documentation on <a
						href="https://themefic.com/docs/uacf7/free-addons/contact-form-7-country-dropdown-with-flag/"
						target="_blank">Country Dropdown</a> and <a
						href="https://themefic.com/docs/uacf7/pro-addons/contact-form-7-autocomplete/" target="_blank">IP Geo
						Fields (Autocomplete)</a>.</div>
			</fieldset>
		</div>

		<div class="insert-box">
			<input type="text" name="<?php echo esc_attr( $uacf7_field_type ); ?>" class="tag code" readonly="readonly"
				onfocus="this.select()" />

			<div class="submitbox">
				<input type="button" class="button button-primary insert-tag"
					value="<?php echo esc_attr( __( 'Insert Tag', 'ultimate-addons-cf7' ) ); ?>" />
			</div>
		</div>
		<?php
	}

	public function uacf7_tag_generator_country_autocomplete_field( $field ) {
		?>
		<tr class="uacf7-spacer"></tr>
		<tr>
			<th scope="row"><label
					for="country_auto_complete"><?php echo esc_html( __( 'Auto complete', 'ultimate-addons-cf7' ) ); ?></label>
			</th>
			<td><input id="country_auto_complete" type="checkbox" name="country_auto_complete" class="option" value="on">
				Autocomplete country using user's network IP.</td>
		</tr>
		<tr class="uacf7-spacer"></tr>
		<?php
	}

	/** Dynamic Selections States */

	public function uacf7_tag_generator_dynamic_selection( $field ) {
		?>
		<tr>
			<th scope="row"><label
					for="dynamic_selection"><?php echo esc_html( __( 'Dynamic Selection', 'ultimate-addons-cf7' ) ); ?></label>
			</th>
			<td><input id=" " type="checkbox" name="ds_country" class="option" value="on">
				<?php echo esc_html( __( "Dynamically Populate Countries, States, and Cities", "ultimate-addons-cf7" ) ); ?>
			</td>
		</tr>
		<tr class="uacf7-spacer"></tr>
		<?php
	}


	public function uacf7_tag_generator_default_country_field( $field ) {
		?>
		<tr>
			<th scope="row"><label><?php echo esc_html( __( 'Show Specific Countries', 'ultimate-addons-cf7' ) ); ?></label>
			</th>
			<td><textarea class="values" name="values" id="tag-generator-panel-product-id" cols="30" rows="10"
					placeholder="Ex : US"></textarea><br> Please enter the selected Country ISO codes, one code per line.</a>
			</td>
		</tr>
		<tr class="uacf7-spacer"></tr>
		<tr>
			<th scope="row"><label
					for="tag-defaul-panel-text-class"><?php echo esc_html( __( 'Default Country', 'ultimate-addons-cf7' ) ); ?></label>
			</th>
			<td><input type="text" name="default" class="defaultvalue oneline option" id="tag-defaul-panel-text-class"
					placeholder="Ex : US"></td>
		</tr>
		<?php
	}

	/*
						 Default country and selected country display attr
					  */

	public function uacf7_get_country_attr( $atts, $tag ) {
		$default = $tag->get_option( 'default' );
		$autocomplete = $tag->get_option( 'autocomplete', '', true );
		$values = $tag->values;
		$ip = getVisIpAddr();
		$addr = @unserialize( file_get_contents( 'http://ip-api.com/php/' . $ip ) );
		if ( $autocomplete == 'true' && ! empty( $addr['countryCode'] ) ) {
			$country = strtolower( $addr['countryCode'] );
		} else {
			$country = '';
		}

		if ( is_array( $values ) ) {
			$values = array_map( 'strtolower', $values );
		}
		if ( ! empty( $default ) ) {
			$default = $default[0];
		} else {
			$default = '';
		}
		if ( $country != '' ) {
			$atts['country-code'] = $country;
		} else {
			$atts['country-code'] = strtolower( $default );
		}

		$atts['only-countries'] = json_encode( $values );
		return $atts;

	}

	/*
						 Admin menu- save ip geo 
						 */
	public function uacf7_save_ip_geo_fields( $sanitary_values, $input ) {

		if ( isset( $input['uacf7_enable_ip_geo_fields'] ) ) {
			$sanitary_values['uacf7_enable_ip_geo_fields'] = $input['uacf7_enable_ip_geo_fields'];
		}
		return $sanitary_values;
	}

}
new UACF7_IP_GEOLOCATION();


